@@ -1,20 +1,21 @@
 #!/bin/sh
 #
 # autogen.sh glue for CMU Cyrus IMAP
-# $Id: autogen.sh,v 1.2 2002/07/15 16:13:37 hmh Exp $
 #
-# Requires: automake, autoconf, dpkg-dev
+# Requires: automake1.8, autoconf, dpkg-dev
+# You probably want to build-conflicts: autoconf2.13, automake1.4
 set -e
 
 # Refresh GNU autotools toolchain.
 for i in config.guess config.sub missing install-sh mkinstalldirs ; do
-	test -r /usr/share/automake/${i} && {
+	test -r /usr/share/automake-1.8/${i} && {
 		rm -f ${i}
-		cp /usr/share/automake/${i} .
+		cp /usr/share/automake-1.8/${i} .
 	}
 	chmod 755 ${i}
 done
 
+#will fail if autoconf2.13 is installed, due to diversions
 aclocal -I cmulocal
 autoheader
 #automake --verbose --foreign --add-missing
